4.2.0 (2023-07-25)
==================
🎉 New features
---------------

- CubicWeb is now compatible with python 3.11
- enable a default session factory in new cubes skeleton pyramid.ini
- support yams < 1.*, before it was < 0.49.*
